@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10632 2017-12-11 09:38:08Z David $
+# $Id: admin.py 10664 2017-12-19 10:35:03Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-11 17:38:08 +0800 (Mon, 11 Dec 2017) $
-# $Revision: 10632 $
+# $Date: 2017-12-19 18:35:03 +0800 (Tue, 19 Dec 2017) $
+# $Revision: 10664 $
 
 from django import forms
 from django.contrib import admin
@@ -21,7 +21,10 @@ from django.utils.translation import gettext as _
 from django.core.urlresolvers import reverse
 
 from emencia.django.newsletter.models import Newsletter
-from emencia.django.newsletter.admin import NewsletterAdmin
+# #FIXME: Django forms dependencies issues, 
+# see https://code.nuwainfo.com/trac/mercurius/ticket/3022
+# from emencia.django.newsletter.admin import NewsletterAdmin
+from Theophrastus.admin import NewsletterTinyMCEAdmin as NewsletterAdmin
 
 from TinyMCEWidget import CustomTinyMCEWidget
 
@@ -49,7 +52,7 @@ class NewsletterTinyMCEForm(forms.ModelForm):
         fields = '__all__'
 
 class NewsletterTinyMCEAdmin(NewsletterAdmin):
-
+    
     list_display = ('title', 'getMailingList', 'getServer', 'status',
                     'formatedSendingDate', 'formatedCreationDate',
                     'formatedModificationDate',
@@ -98,3 +101,4 @@ class NewsletterTinyMCEAdmin(NewsletterAdmin):
 
 admin.site.unregister(Newsletter)
 admin.site.register(Newsletter, NewsletterTinyMCEAdmin)
+
