@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10683 2017-12-26 09:07:37Z David $
+# $Id: admin.py 10685 2017-12-26 10:23:40Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-26 17:07:37 +0800 (Tue, 26 Dec 2017) $
-# $Revision: 10683 $
+# $Date: 2017-12-26 18:23:40 +0800 (Tue, 26 Dec 2017) $
+# $Revision: 10685 $
 
 from django.contrib import admin
 from django.contrib.admin.views.main import ChangeList
@@ -141,7 +141,7 @@ class GroupChangeList(ChangeList):
 
         return []
 
-    def getQuerySet(self, request='', original=False):
+    def getQuerySet(self, request=None, original=False):
         apps = self.getApps()
 
         if original:
@@ -262,7 +262,7 @@ class MailingListChangeList(ChangeList):
     def __init__(self, request, *args, **kwargs):
         super(MailingListChangeList, self).__init__(request, *args, **kwargs)
 
-    def getQuerySet(self, request='', original=False):
+    def getQuerySet(self, request=None, original=False):
         if original:
             queryset = MailingList.objects.all()
             return queryset
@@ -276,7 +276,7 @@ class MailingListChangeList(ChangeList):
             return queryset.exclude(newsletter__group__id__in=ids)
 
     def get_queryset(self, request):
-        return self.getQuerySet(request=request, original=True)
+        return self.getQuerySet(request=request)
 
 class AppMailingListFilter(admin.SimpleListFilter):
     # Human-readable title which will be displayed in the
@@ -403,7 +403,7 @@ class NewsletterIntegrationChangeList(ChangeList):
             return [q['id'] for q in _group.newsletters.values('id')]
         return []
 
-    def getQuerySet(self, request='', original=False):
+    def getQuerySet(self, request=None, original=False):
 
         ids = self.getIdsByGroup()
 
@@ -418,7 +418,7 @@ class NewsletterIntegrationChangeList(ChangeList):
             if ids:
                 return queryset.filter(id__in=ids)
             else:
-                return queryset
+                return queryset.exclude(id__in=self.getAllAppIds())
             
 
     def get_queryset(self, request):
